@@ -6,9 +6,6 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
      # VALUE      Produces rim for Step 1. If there are no factors, random choice 
      #            of inner.rank rows from entire dataset. If there are factors, use 
      #            variablelist and picksome to get a constrained choice of innersample.rows.
-# following is no longer true 
-    #            output is a list of 2 levels, the first is all obs in Step 1, the second is the
-     #            same but is a list of length = number of subsets each level of with is obs by level.
      #
      # INPUT      yesfactor      Logical. TRUE if there are factors in the X matrix 
      #            df1            Data frame being analyzed by forward search. Presence of
@@ -19,18 +16,10 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
      #            initial.sample Number of random samples from which to take rim
      #            formula        Formula for fixed effects in lm always without factors
      #            ycol           Response column number
-     #            nopl           n.obs.per.level multiplier
+     #            nopl           n.obs.per.level 
      #            b.d            begin.diagnose Ranges from 25 to 45
      #
-     # NOTES
-     #     This function does not involve any inner or outer factors such as grouping variables.
-     #     Form inner groups available in data using variablelist.  rim will have nopl 
-     #     observation from each of these inner groups plus enough randomly selected other 
-     #     observations to make up a set of inner.rank observations, if any more are needed.
-     #     If there are no inner groups, need to do the augmentation on the full dataset after
-     #     taking inner.rank * nobs.per.level observations.
      #
-     
      spacehere <- "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%      aStep1           "    
      
      #######################################
@@ -66,7 +55,7 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
                dimpickm2 <- max(inner.rank, nopl)
                obsindex <- zlist[[i]][1:dimpickm2,1]
  
-                           if(b.d <=35 ){ print("",quote=FALSE);print(paste(spacehere,"Section 35", i, sep=" "),quote=FALSE);
+                           if(b.d <=35 ){ print("",quote=FALSE);print(paste(spacehere,"Section 35   ", i, sep=" "),quote=FALSE);
                                          Hmisc::prn(yesfactor);Hmisc::prn(inner.rank);Hmisc::prn(obsindex)   }
 
                Obs <- match(obsindex,data[,1])
@@ -85,7 +74,7 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
                augx <- augx[order(augx[,2]),]                            # order the squared errors
                medaugx[i,] <- augx[floor((dimdata.1 + inner.rank)/2),]   # place the median in a matrix
 
-                           if(b.d <=37 ){print("",quote=FALSE); print(paste(spacehere,"Section 37 ", i, sep=" "),quote=FALSE);
+                           if(b.d <=37 ){print("",quote=FALSE); print(paste(spacehere,"Section 37    sample: ", i, sep=" "),quote=FALSE);
                                Hmisc::prn(smalldata);Hmisc::prn(this.form);
                                Hmisc::prn(utils::head(augx));Hmisc::prn(utils::tail(augx));Hmisc::prn(medaugx[i,])    }
           }       #   i
@@ -102,9 +91,9 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
           if(is.matrix(locatemin))  locatemin <- locatemin[1,]     # resolve >1 equal minima
           lcm3 <- locatemin[3]       # pull out the randset to be used 
           zliststar <- zlist[[lcm3]]     # this is the permutation to use
-         #
+
           rim <- c(zliststar[1:length(obsindex), 1])
-         return(rim)
+          return(rim)
      }       # end supfun
 
 
@@ -113,7 +102,7 @@ function (yesfactor, df1, inner.rank, initial.sample, formula, ycol, nopl, b.d)
  
                            if(b.d <=31 ){ print("",quote=FALSE);print(paste(spacehere,"Section 31",sep=" "),quote=FALSE);
                                  Hmisc::prn(yesfactor);Hmisc::prn(utils::head(df1));Hmisc::prn(inner.rank);
-                                 Hmisc::prn(formula);Hmisc::prn(ycol)   }
+                                 Hmisc::prn(dim(df1));Hmisc::prn(formula);Hmisc::prn(ycol)   }
 
      if(yesfactor){
           nlevels <- length(df1)
