@@ -10,7 +10,7 @@ function(forn,
      Cairo=TRUE,
      printgraph=TRUE,
      legend="Dummy legend name",
-     diagnose=FALSE, verbose=TRUE)
+     verbose=TRUE)
 {
      #                          plotdiag.params.random
      #
@@ -24,7 +24,7 @@ function(forn,
           print("Call:", quote = FALSE)
           print(MC)
           print("", quote = FALSE)
-     }    # verbose
+     }    
      #################
      # Plot function #
      #################
@@ -43,10 +43,10 @@ function(forn,
           YVAR <- data[,ycol]
           COV1 <- data[,cov1col]
           dfplot <- data.frame(XVAR,YVAR,COV1)
-                      if(diagnose)Hmisc::prn(dfplot)
+#                      if(diagnose)Hmisc::prn(dfplot)
           FACET <- data[,facetcol]
           dfplot <- data.frame(dfplot,FACET)
-                     if(diagnose)Hmisc::prn(dfplot)
+#                     if(diagnose)Hmisc::prn(dfplot)
           if(is.null(facetcol)){
                out <- ggplot2::ggplot(data=dfplot,ggplot2::aes(XVAR,YVAR,COV1)) + ggplot2::geom_point(ggplot2::aes(shape = COV1))
                out$labels$shape <- legendname
@@ -110,7 +110,7 @@ function(forn,
                usefacets <- FALSE
           }
           betacoeffs <- as.data.frame(tibble::tibble(col1,col2,col3))
-                                  if(diagnose) Hmisc::prn(betacoeffs)
+#                                  if(diagnose) Hmisc::prn(betacoeffs)
           index <- betacoeffs[,2] > 0
           betacoeffs <- betacoeffs[index,]
           wmf2 <- paste(wmf,".wmf",sep="")    
